@@ -5,8 +5,10 @@ from typing import Any, Callable, Dict, List, Optional, Tuple, Type, Union
 from moonstreamdb.db import yield_db_session, yield_db_session_ctx
 from moonstreamdb.models import (
     EthereumBlock,
+    EthereumLabel,
     EthereumTransaction,
     PolygonBlock,
+    PolygonLabel,
     PolygonTransaction,
 )
 from psycopg2.errors import UniqueViolation  # type: ignore
@@ -21,8 +23,8 @@ from web3.types import BlockData
 from .data import AvailableBlockchainType, DateRange
 from .settings import (
     MOONSTREAM_CRAWL_WORKERS,
-    MOONSTREAM_ETHEREUM_IPC_PATH,
-    MOONSTREAM_POLYGON_IPC_PATH,
+    MOONSTREAM_ETHEREUM_WEB3_PROVIDER_URI,
+    MOONSTREAM_POLYGON_WEB3_PROVIDER_URI,
 )
 
 logger = logging.getLogger(__name__)
@@ -40,9 +42,9 @@ def connect(blockchain_type: AvailableBlockchainType, web3_uri: Optional[str] =
 
     if web3_uri is None:
         if blockchain_type == AvailableBlockchainType.ETHEREUM:
-            web3_uri = MOONSTREAM_ETHEREUM_IPC_PATH
+            web3_uri = MOONSTREAM_ETHEREUM_WEB3_PROVIDER_URI
         elif blockchain_type == AvailableBlockchainType.POLYGON:
-            web3_uri = MOONSTREAM_POLYGON_IPC_PATH
+            web3_uri = MOONSTREAM_POLYGON_WEB3_PROVIDER_URI
         else:
             raise Exception("Wrong blockchain type provided for web3 URI")
 
@@ -78,6 +80,24 @@ def get_block_model(
     return block_model
 
 
+def get_label_model(
+    blockchain_type: AvailableBlockchainType,
+) -> Type[Union[EthereumLabel, PolygonLabel]]:
+    """
+    Depends on provided blockchain type: Ethereum or Polygon,
+    set proper block label model: EthereumLabel or PolygonLabel.
+    """
+    label_model: Type[Union[EthereumLabel, PolygonLabel]]
+    if blockchain_type == AvailableBlockchainType.ETHEREUM:
+        label_model = EthereumLabel
+    elif blockchain_type == AvailableBlockchainType.POLYGON:
+        label_model = PolygonLabel
+    else:
+        raise Exception("Unsupported blockchain type provided")
+
+    return label_model
+
+
 def get_transaction_model(
     blockchain_type: AvailableBlockchainType,
 ) -> Type[Union[EthereumTransaction, PolygonTransaction]]:
